@@ -105,6 +105,30 @@ def _get_LF_output_fmt(short_name, filetype='snapshot'):
         ret = {'file': 'unknown', 'short_name': short_name, 'long_name': short_name.replace('_', ' '), 'symbol': '', 'units': '', 'dtype': '', 'infile': True, }
     return ret
 
+class LFSource(object):
+    def __init__(self, x=None, y=None, lat=None, lon=None, radius=None, time=None, flux=None, conc=None):
+        self.x = x
+        self.y = y
+        self.lat = lat
+        self.lon = lon
+        self.radius = radius
+        self.time = time
+        self.flux = flux
+        self.conc = conc
+
+    def volume(self):
+        return np.trapz(self.flux, self.time)
+    
+    def peak_flux(self):
+        return np.amax(self.flux)
+    
+    def peak_time(self):
+        i = np.argmax(self.flux)
+        return self.time[i]
+    
+    def duration(self):
+        return self.time[-1]-self.time[0]
+
 class LaharFlowData(object):
     def __init__(self,LaharFlowDir,zipped=False):
 
@@ -134,6 +158,8 @@ class LaharFlowData(object):
             assert(os.path.isfile(infoFile)), 'Run info file {} does not exist'.format(infoFile)
         self.infoFile = infoFile
 
+        self.sources = []
+
         with open(infoFile) as f:
             for ln, line in enumerate(f):
                 if "Input file name" in line:
@@ -214,14 +240,19 @@ class LaharFlowData(object):
                     self.LandUsePath = line.split('=',1)[1].strip(' \t\n\r')
                 if "Land use file" in line:
                     self.LandUseFile = line.split('=',1)[1].strip(' \t\n\r')
-                # if "Number of flux sources" in line:
-                # 	self.num_flux = int(line.split('=',1)[1])
-                # 	src_count = 0
-                # 	while src_count<self.num_flux:
-                # 		for k in range(0,10):
-                # 			next(f,None)
-                # 			print(ln,' ',line)
-                # 		src_count+=1
+                if 'Source' in line:
+                        s_x = float(next(f).split('=',1)[1].rstrip())
+                        s_y = float(next(f).split('=',1)[1].rstrip())
+                        s_lat = float(next(f).split('=',1)[1].rstrip())
+                        s_lon = float(next(f).split('=',1)[1].rstrip())
+                        s_radius = float(next(f).split('=',1)[1].rstrip())
+                        s_time = np.fromstring(next(f).split('=',1)[1].rstrip().replace('(','').replace(')',''), sep=',')
+                        s_flux = np.fromstring(next(f).split('=',1)[1].rstrip().replace('(','').replace(')',''), sep=',')
+                        s_conc = np.fromstring(next(f).split('=',1)[1].rstrip().replace('(','').replace(')',''), sep=',')
+
+                        self.sources.append(LFSource(x=s_x, y=s_y, lat=s_lat, lon=s_lon, radius=s_radius,
+                                                     time=s_time, flux=s_flux, conc=s_conc))
+
                     
             self.files=[]
             self.txt_files=[]
@@ -334,12 +365,14 @@ class LaharFlowData(object):
                     if keyword=="Solid diameter":
                         self.Solid_diameter = float(value)
                         parameters.append('Solid_diameter')
+
                 except:
                     pass
         self.parameters = parameters
 
     def _get_parameters_from_runinfo(self):
         parameters = []
+
         with open(self.infoFile) as f:
             for line in f:
                 delim = '=' if '=' in line else ':'
@@ -395,6 +428,18 @@ class LaharFlowData(object):
                     if keyword=="Erosion":
                         self.Erosion = value
                         parameters.append('Erosion')
+                    if 'Source' in keyword:
+                        s_x = float(next(f).split('=',1)[1].rstrip())
+                        s_y = float(next(f).split('=',1)[1].rstrip())
+                        s_lat = float(next(f).split('=',1)[1].rstrip())
+                        s_lon = float(next(f).split('=',1)[1].rstrip())
+                        s_radius = float(next(f).split('=',1)[1].rstrip())
+                        s_time = np.fromstring(next(f).split('=',1)[1].rstrip().replace('(','').replace(')',''))
+                        s_flux = np.fromstring(next(f).split('=',1)[1].rstrip().replace('(','').replace(')',''))
+                        s_conc = np.fromstring(next(f).split('=',1)[1].rstrip().replace('(','').replace(')',''))
+
+                        self.sources.append(LFSource(x=s_x, y=s_y, lat=s_lat, lon=s_lon, radius=s_radius,
+                                                     time=s_time, flux=s_flux, conc=s_conc))
                 except:
                     pass
                     
@@ -997,7 +1042,7 @@ class LaharFlowData(object):
                 self.MaxConc = None
             return
         else:
-            print ('make this work')
+            print ('cannot get max conc from text files easily')
             #raise RuntimeWarning('No data to determine maximum depth')
         return
 
